/*
 * Copyright 2013 Simon Willeke
 * contact: hamstercount@hotmail.com
 */

/*
    This file is part of Blockinger.

    Blockinger is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Blockinger is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Blockinger.  If not, see <http://www.gnu.org/licenses/>.

    Diese Datei ist Teil von Blockinger.

    Blockinger ist Freie Software: Sie knnen es unter den Bedingungen
    der GNU General Public License, wie von der Free Software Foundation,
    Version 3 der Lizenz oder (nach Ihrer Option) jeder spteren
    verffentlichten Version, weiterverbreiten und/oder modifizieren.

    Blockinger wird in der Hoffnung, dass es ntzlich sein wird, aber
    OHNE JEDE GEWHELEISTUNG, bereitgestellt; sogar ohne die implizite
    Gewhrleistung der MARKTFHIGKEIT oder EIGNUNG FR EINEN BESTIMMTEN ZWECK.
    Siehe die GNU General Public License fr weitere Details.

    Sie sollten eine Kopie der GNU General Public License zusammen mit diesem
    Programm erhalten haben. Wenn nicht, siehe <http://www.gnu.org/licenses/>.
 */

package org.blockinger.game.components;

import org.blockinger.game.R;
import org.blockinger.game.activities.GameActivity;

import android.content.Context;
import android.media.AudioManager;
import android.media.MediaPlayer;
import android.preference.PreferenceManager;

public class Sound extends Component {

	private MediaPlayer tetrisSoundPlayer;
	private MediaPlayer dropSoundPlayer;
	private MediaPlayer clearSoundPlayer;
	private MediaPlayer gameOverPlayer;
	private MediaPlayer buttonSoundPlayer;
	
	public Sound(GameActivity c) {
		super(c);
		tetrisSoundPlayer = MediaPlayer.create(c,R.raw.seqlong);
		tetrisSoundPlayer.setLooping(false);
		tetrisSoundPlayer.setVolume(0.01f * PreferenceManager.getDefaultSharedPreferences(c).getInt("pref_soundvolume", 60), 0.01f * PreferenceManager.getDefaultSharedPreferences(c).getInt("pref_soundvolume", 60));

		dropSoundPlayer = MediaPlayer.create(c,R.raw.drop2);
		dropSoundPlayer.setLooping(false);
		dropSoundPlayer.setVolume(0.01f * PreferenceManager.getDefaultSharedPreferences(c).getInt("pref_soundvolume", 60), 0.01f * PreferenceManager.getDefaultSharedPreferences(c).getInt("pref_soundvolume", 60));

		buttonSoundPlayer = MediaPlayer.create(c,R.raw.keypressstandard);
		buttonSoundPlayer.setLooping(false);
		buttonSoundPlayer.setVolume(0.01f * PreferenceManager.getDefaultSharedPreferences(c).getInt("pref_soundvolume", 60), 0.01f * PreferenceManager.getDefaultSharedPreferences(c).getInt("pref_soundvolume", 60));
	    
		clearSoundPlayer = MediaPlayer.create(c,R.raw.synthaccord);
		clearSoundPlayer.setLooping(false);
		clearSoundPlayer.setVolume(0.01f * PreferenceManager.getDefaultSharedPreferences(c).getInt("pref_soundvolume", 60), 0.01f * PreferenceManager.getDefaultSharedPreferences(c).getInt("pref_soundvolume", 60));
		
		gameOverPlayer = MediaPlayer.create(c,R.raw.gameover);
		gameOverPlayer.setLooping(false);
		gameOverPlayer.setVolume(0.015f * PreferenceManager.getDefaultSharedPreferences(c).getInt("pref_soundvolume", 60), 0.01f * PreferenceManager.getDefaultSharedPreferences(c).getInt("pref_soundvolume", 60));
	}
	
	public void clearSound() {
		if(((AudioManager)host.getSystemService(Context.AUDIO_SERVICE)).getRingerMode() != AudioManager.RINGER_MODE_NORMAL)
			return;
		//if(clearSoundPlayer.isPlaying()) 
		//	clearSoundPlayer.stop();
		clearSoundPlayer.seekTo(0);
		clearSoundPlayer.start();
	}
	
	public void buttonSound() {
		if(((AudioManager)host.getSystemService(Context.AUDIO_SERVICE)).getRingerMode() != AudioManager.RINGER_MODE_NORMAL)
			return;
		if(!PreferenceManager.getDefaultSharedPreferences(host).getBoolean("pref_button_sound", true))
			return;
		//if(buttonSoundPlayer.isPlaying()) 
		//	buttonSoundPlayer.stop();
		buttonSoundPlayer.seekTo(0);
		buttonSoundPlayer.start();
	}
	
	public void dropSound() {
		if(((AudioManager)host.getSystemService(Context.AUDIO_SERVICE)).getRingerMode() != AudioManager.RINGER_MODE_NORMAL)
			return;
		//if(dropSoundPlayer.isPlaying())
		//	dropSoundPlayer.stop();
		dropSoundPlayer.seekTo(0);
		dropSoundPlayer.start();
	}
	
	public void release() {
		if(((AudioManager)host.getSystemService(Context.AUDIO_SERVICE)).getRingerMode() != AudioManager.RINGER_MODE_NORMAL)
			return;
		dropSoundPlayer.release();
		clearSoundPlayer.release();
		tetrisSoundPlayer.release();
		gameOverPlayer.release();
	}

	public void tetrisSound() {
		if(((AudioManager)host.getSystemService(Context.AUDIO_SERVICE)).getRingerMode() != AudioManager.RINGER_MODE_NORMAL)
			return;
		//if(tetrisSoundPlayer.isPlaying())
		//	tetrisSoundPlayer.stop();
		tetrisSoundPlayer.seekTo(0);
		tetrisSoundPlayer.start();
	}

	public void gameOverSound() {
		if(((AudioManager)host.getSystemService(Context.AUDIO_SERVICE)).getRingerMode() != AudioManager.RINGER_MODE_NORMAL)
			return;
		//if(tetrisSoundPlayer.isPlaying())
		//	tetrisSoundPlayer.stop();
		gameOverPlayer.seekTo(0);
		gameOverPlayer.start();
	}
}
